package de.intevation.flys.client.client.ui;

import java.util.Date;

import com.google.gwt.core.client.GWT;

import com.smartgwt.client.widgets.Canvas;
import com.smartgwt.client.widgets.Img;
import com.smartgwt.client.widgets.Label;
import com.smartgwt.client.widgets.layout.HLayout;
import com.smartgwt.client.widgets.layout.VLayout;

import de.intevation.flys.client.shared.model.Collection;
import de.intevation.flys.client.shared.model.OutputMode;
import de.intevation.flys.client.client.Config;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class ChartOutputTab extends OutputTab {

    /** The canvas that wraps the chart toolbar.*/
    protected Canvas tbarPanel;

    /** The canvas that wraps the theme editor.*/
    protected Canvas left;

    /** The canvas that wraps the chart.*/
    protected Canvas right;


    /**
     * The default constructor to create a new ChartOutputTab.
     *
     * @param title The title of this tab.
     * @param collection The Collection which this chart belongs to.
     * @param mode The OutputMode.
     */
    public ChartOutputTab(String title, Collection collection, OutputMode mode){
        super(title, collection, mode);

        tbarPanel = new Canvas();
        left      = new Canvas();
        right     = new Canvas();

        tbarPanel.setBorder("1px solid black");
        tbarPanel.setHeight(25);
        left.setBorder("1px solid black");
        left.setWidth("25%");
        right.setWidth("*");

        VLayout vLayout = new VLayout();
        vLayout.setMembersMargin(2);

        HLayout hLayout = new HLayout();
        hLayout.setWidth100();
        hLayout.setHeight100();
        hLayout.setMembersMargin(10);

        hLayout.addMember(left);
        hLayout.addMember(right);

        right.addChild(createChartPanel());
        left.addChild(createThemeControlPanel());
        tbarPanel.addChild(createTBarPanel());

        vLayout.addMember(tbarPanel);
        vLayout.addMember(hLayout);

        setPane(vLayout);
    }


    protected Canvas createTBarPanel() {
        Label label = new Label("Werkzeugleiste");
        label.setHeight(25);
        label.setMargin(5);

        return label;
    }


    protected Canvas createChartPanel() {
        Img chart  = getChartImg();
        chart.setWidth100();
        chart.setHeight100();

        return chart;
    }


    protected Canvas createThemeControlPanel() {
        Label label = new Label("Themensteuerung");
        label.setHeight(25);
        label.setMargin(5);

        return label;
    }


    /**
     * Builds the chart image and returns it.
     *
     * @return the chart image.
     */
    protected Img getChartImg() {
        return new Img(getImgUrl());
    }


    /**
     * Builds the URL that points to the chart image.
     *
     * @return the URL to the chart image.
     */
    protected String getImgUrl() {
        Config config = Config.getInstance();

        String imgUrl = GWT.getModuleBaseURL();
        imgUrl += "chart";
        imgUrl += "?uuid=" + collection.identifier();
        imgUrl += "&type=" + mode.getName();
        imgUrl += "&server=" + config.getServerUrl();
        imgUrl += "&locale=" + config.getLocale();
        imgUrl += "&timestamp=" + new Date().getTime();

        return imgUrl;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
